==> spark-3.4.4.tgz: spark-3.4.4/python/pyspark/sql/tests/connect/test_parity_pandas_map.py <==
#
# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements.  See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to You under the Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.  You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from pyspark.sql.tests.pandas.test_pandas_map import MapInPandasTestsMixin
from pyspark.testing.connectutils import ReusedConnectTestCase


class MapInPandasParityTests(MapInPandasTestsMixin, ReusedConnectTestCase):
    def test_empty_dataframes_with_less_columns(self):
        self.check_empty_dataframes_with_less_columns()

    def test_other_than_dataframe(self):
        self.check_other_than_dataframe()


if __name__ == "__main__":
    import unittest
    from pyspark.sql.tests.connect.test_parity_pandas_map import *  # noqa: F401

    try:
        import xmlrunner  # type: ignore[import]

        testRunner = xmlrunner.XMLTestRunner(output="target/test-reports", verbosity=2)
    except ImportError:
        testRunner = None
    unittest.main(testRunner=testRunner, verbosity=2)

==> spark-3.5.3.tgz: spark-3.5.3/python/pyspark/sql/tests/connect/test_parity_pandas_map.py <==
#
# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements.  See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to You under the Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.  You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import unittest


from pyspark.sql.tests.pandas.test_pandas_map import MapInPandasTestsMixin
from pyspark.testing.connectutils import ReusedConnectTestCase


class MapInPandasParityTests(MapInPandasTestsMixin, ReusedConnectTestCase):
    def test_other_than_dataframe_iter(self):
        self.check_other_than_dataframe_iter()

    def test_dataframes_with_other_column_names(self):
        self.check_dataframes_with_other_column_names()

    def test_dataframes_with_duplicate_column_names(self):
        self.check_dataframes_with_duplicate_column_names()

    def test_dataframes_with_less_columns(self):
        self.check_dataframes_with_less_columns()

    @unittest.skip("Fails in Spark Connect, should enable.")
    def test_dataframes_with_incompatible_types(self):
        self.check_dataframes_with_incompatible_types()

    def test_empty_dataframes_with_less_columns(self):
        self.check_empty_dataframes_with_less_columns()

    def test_empty_dataframes_with_other_columns(self):
        self.check_empty_dataframes_with_other_columns()


if __name__ == "__main__":
    import unittest
    from pyspark.sql.tests.connect.test_parity_pandas_map import *  # noqa: F401

    try:
        import xmlrunner  # type: ignore[import]

        testRunner = xmlrunner.XMLTestRunner(output="target/test-reports", verbosity=2)
    except ImportError:
        testRunner = None
    unittest.main(testRunner=testRunner, verbosity=2)
